==> haskell-pointed-5.0.1-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pointed
version:              5.0.1
visibility:           public
id:                   pointed-5.0.1-4a0Ps5JfEfHB6lllYmE5Zm
key:                  pointed-5.0.1-4a0Ps5JfEfHB6lllYmE5Zm
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  6bea1d9e38c78daf1bbac1f6ef591e9d
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-8.10.2/site-local/pointed-5.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/pointed-5.0.1
hs-libraries:         HSpointed-5.0.1-4a0Ps5JfEfHB6lllYmE5Zm
depends:
    base-4.14.1.0 comonad-5.0.6-7zsbNzyscAAEyXYpxXSY0L
    containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hashable-1.3.0.0-IhQ3DGT3Mv7KNucUf0KrvO
    kan-extensions-5.2-KdlF3Ij9yVO8n9fpA0WlhG
    semigroupoids-5.3.4-726ArNmPc7h1AkDhQGaKZT stm-2.5.0.0
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
    unordered-containers-0.2.12.0-L7e0ebfosZDK7txbADKTIQ

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-165-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pointed
version:              5.0.1
visibility:           public
id:                   pointed-5.0.1-D7UOMKzMgfX73mEg44LGKL
key:                  pointed-5.0.1-D7UOMKzMgfX73mEg44LGKL
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  a8a3138a25b765b69723b5fa1db0b19c
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-8.10.2/site-local/pointed-5.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/pointed-5.0.1
hs-libraries:         HSpointed-5.0.1-D7UOMKzMgfX73mEg44LGKL
depends:
    base-4.14.1.0 comonad-5.0.6-GpOlioFzj4kKMcFNwdQg0i
    containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hashable-1.3.0.0-1lZSCDGnvrhIxi1kvployh
    kan-extensions-5.2-4Vyhe55TJxy4aZ8getx2W6
    semigroupoids-5.3.4-68mjy0MAHel1j0CNDz8RBm stm-2.5.0.0
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
    unordered-containers-0.2.12.0-7Y0visJG1jrKru9xZJvbq5

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
